      SUBROUTINE stdz2p(P,H1,L,TCENT,RHO)                                      
C
C COMPUTES PRESSURE, TEMPERATURE, AND DENSITY VALUES FROM INPUT HEIGHTS
C  BASED ON US STANDARD ATMOSPHERE, 1976
C  VALUES NOT VALID ABOVE 84852 KM.
C
C INPUT
C       H1    - HEIGHT IN FEET OR METERS
C       L     - UNITS FLAG - 0=METERS, 1=FEET
C OUTPUT
C       P     - PRESSURE IN MB
C       TCENT - TEMPERATURE IN DEG C
C       RHO   - DENSITY IN KG/M3
C
      real r
      DIMENSION HBASE(10),HTOP(10),TB(10),GRAD(10),ABS(10)
      DIMENSION PB(11),RB(10)
      save hbase,htop,tb,grad,abs,pb,rb
      DATA HBASE/ 0.,1.1E4,2.E4,3.2E4,4.7E4,5.1E4,7.1E4,3*84852.0/
      DATA HTOP /1.1E4,2.E4,3.2E4,4.7E4,5.1E4,7.1E4,4*84852.0/
      DATA TB / 15.,2*-56.5,-44.5,2*-2.5,-58.5,3*-86.2/
      DATA GRAD/-.0065,0.,.001,.0028,0.,-.0028,-.002,3*0./
      DATA CHECK/0./                                                            
C     H1 IS ALTITUDE, IF IN METERS SET L .LE. 0.  IF IN FEET SET L .GE. 1       
C     P IS PRESSURE IN MB.  TCENT IS TEMP CELSIUS.  RHO IS DENSITY IN KG/M**3   
c
      ABSZ = 273.15                                                             
      PZERO=1013.250                                                            
      G=980.665                                                                 
      R = 83143200./28.9644

c     generate atmosphere tables
c       (temperature, pressure and density)
      IF(CHECK.NE.0.) GO TO 16                                                  
      PB(1) = PZERO                                                             

c     compute temperature in degrees k
      DO 3  I=1,8                                                               
        ABS(I) = TB(I) + ABSZ
    3 CONTINUE                                                                  

      DO 15  I=1,8                                                             
        IF (GRAD(I) .EQ. 0) then
C         HERE FOR TEMP GRADIENT ZERO
          PB(I+1) = PB(I)
     &           *2.7182818**((-100.*G/(R*ABS(I)))*(HTOP(I)-HBASE(I)))
        else
C         HERE FOR TEMP GRADIENT NOT ZERO
          PB(I+1) = PB(I)*((ABS(I+1)/ABS(I))**(100.*G/(-GRAD(I)*R)))
        end if
        RB(I) = 1000.*PB(I)/(R*ABS(I)) * 1000.
   15 CONTINUE

      CHECK=10.                                                                 
   16 CONTINUE                                                                  
C                                                                               
c     table generated, interpolate for values at H
      IF(L. lt.1) then
        H = H1
      else
        H = H1*.3048
      end if

C  FIND THE ATMOSPHERIC LAYER WE ARE IN                                         
      DO 55  I = 1,8                                                            
        IF  (H .GT. HBASE(I+1)) GO TO 55
        IF (GRAD(I) .eq. 0) then
C         ISOTHERMAL LAYER     
          P= PB(I)*EXP((H-HBASE(I))*(-G)/(.01*R*ABS(I)))
        else
C         TEMP GRADIENT NOT ZERO 
          P= PB(I)*((H-HBASE(I))*GRAD(I)
     &      /ABS(I)+1)**(-100.*G/(GRAD(I)*R))           
        end if
        T = ABS(I) + GRAD(I)*(H-HBASE(I))
        TCENT = T - ABSZ                
        RHO = 1.E6* P/(R*T)            
        RETURN

   55 CONTINUE                                                                  
   56 WRITE(6,98)H
98    FORMAT(' STDATM -  ALTITUDE OUT OF RANGE ',F12.2,//)
      END                                                                       
