      SUBROUTINE visc(GAMMA,GASCO)
C
C     THIS PROGRAM ESTIMATES REYNOLDS NUMBER AND VISCOUS PARAMETERS
C
   10 CONTINUE
C
C     ENTER NEEDED INFO
      write(*,*) ' '
      write(*,*) '          BOUNDARY LAYER PROPERTIES'
      write(*,*) ' '
      write(*,*) 'Laminar boundary layer properties computed assuming'
      write(*,*) '   Blasius profiles (Schlichting)'
      write(*,*) 'Turbulent boundary layer properties computed assuming'
      write(*,*) '   1/7th power law and skin friction equations'
      write(*,*) ' '
      WRITE(*,*) 'Specify static or total conditions: 0 - static'
      write(*,*) '                                    1 - total'
      READ(*,*) IST
      WRITE(*,*) 'Specify Mach Number, Pressure (PSI), Temperature (R)'
      READ(*,*) AMACH,P,T
      WRITE(*,*) 'Specify distance from leading edge (FEET)'
      READ(*,*) XREF
C
C     COMPUTE TOTAL AND STATIC CONDITIONS
      P = P*144.
      FM = 1.+.5*(GAMMA-1.)*AMACH*AMACH
      IF(IST .EQ. 0) THEN
C       COMPUTE TOTAL CONDITIONS
        TT = T*FM
        PT = P*FM**(GAMMA/(GAMMA-1.))
      ELSE
C       COMPUTE STATIC CONDITIONS
        TT = T
        PT = P
        P  = PT*FM**(-GAMMA/(GAMMA-1.))
        T  = TT/FM
      END IF
C
C     COMPUTE REYNOLDS NUMBER
      AMU = .3170E-10 * SQRT(T*T*T) * 734.7 / (T + 216.)
      RHO = P/(GASCO*T)
      C   = SQRT(GAMMA*GASCO*T)
      U   = AMACH*C
      RE  = RHO*U*XREF/AMU
C
C     DYNAMIC PRESSURE
      Q = .5*RHO*U*U
C
C     TURBULENT BOUNDARY LAYER THICKNESS
      RED = 0.14*RE**(6./7.)
      DELTA = RED*AMU/(RHO*U)
      CFA = .025*RE**(-1./7.)
      YP1 = AMU/(SQRT(CFA*RHO*Q))
C
C     LAMINAR BOUNDARY LAYER THICKNESS
      DELTAL = 4.8*XREF*RE**(-.5)
      CFAL = .655*RE**(-.5)
      YP1L = AMU/(SQRT(CFAL*RHO*Q))
C
C     WRITE OUT RUN CONDITIONS
      WRITE(6,*) 'MACH             : ',AMACH
      WRITE(6,*) 'Static P (PSF)   : ',P
      WRITE(6,*) 'Static T (R)     : ',T
      WRITE(6,*) 'Total P (PSF)    : ',PT
      WRITE(6,*) 'Total T (R)      : ',TT
      WRITE(6,*) 'Q (SLUG/FT-SEC2) : ',Q
      WRITE(6,*) 'REYNOLDS NUMBER  : ',RE
      WRITE(6,*) 'Laminar Boundary Layer Data (Y+ is linear)'
      WRITE(6,*) '   Delta(FEET)     : ',DELTAL
      WRITE(6,*) '   Cf              : ',CFAL
      WRITE(6,*) '   Y at Y+=1 (FEET): ',YP1L
      WRITE(6,*) 'Turbulent Boundary Layer Data'
      WRITE(6,*) '   Delta(FEET)     : ',DELTA
      WRITE(6,*) '   Cf              : ',CFA
      WRITE(6,*) '   Y at Y+=1 (FEET): ',YP1
C
C     DECIDE WHAT TO DO NEXT
   20 CONTINUE
      WRITE(*,*) ' ENTER WHAT TO DO NEXT'
      WRITE(*,*) ' 0 ..... RETURN'
      WRITE(*,*) ' 1 ..... COMPUTE NEW CONDITIONS'
      WRITE(*,*) ' 2 ..... COMPUTE PARAMETERS FOR GIVEN GRID SPACING'
      WRITE(*,*) ' 3 ..... FIND Y FOR A GIVEN Y+'
      READ(*,*) INEXT
C
      IF(INEXT .EQ. 0) THEN 
C
C       EXIT OUT
C
      ELSE IF(INEXT .EQ. 1) THEN
        GO TO 10
C
      ELSE IF(INEXT .EQ. 2) THEN
C
        WRITE(*,*) 'Specify spacing for y+ estimate (FEET)'
        READ(*,*) DY
C
C       COMPUTE INITIAL YPLUS,CF
        DU    = U
        TAUW  = AMU*DU/DY
        USTAR = SQRT(TAUW/RHO)
        YPLUS = DY*RHO*USTAR/AMU
        CF = TAUW/Q
C
C       GEOMETRIC GRID STRETCHING PARAMETERS
        G=1.2
        NPTS = ALOG(1. + (G-1)*DELTA/DY)/ALOG(G)
C
        WRITE(*,*) 'Grid Parameters'
        WRITE(6,*) '   Laminar DY/Delta : ',DY/DELTAL
        WRITE(6,*) '   Turb DY/Delta    : ',DY/DELTA
        WRITE(6,*) '   pts in bl (G=1.2): ',NPTS
        WRITE(*,*) '   TAUW initial     : ',TAUW
        WRITE(*,*) '   Y+,Cf initial    : ',YPLUS,CF
        WRITE(*,*) '   DY/XREF         : ',DY/XREF
C
        GO TO 20
C
      ELSE IF(INEXT .EQ. 3) THEN
c
        WRITE(*,*) 'Enter desired Y+'
        read(*,*) ypd
c
        yd = yp1*ypd
        ydl = yp1l*ypd
c
        write(*,*) '   y at Laminar Y+desired (feet)   ',ydl
        write(*,*) '   y at Turbulent Y+desired (feet) ',yd
c
        go to 20
c
      ELSE
C
C       EXIT OUT
C
      END IF
C
  100 CONTINUE
C
      RETURN
      END
