      SUBROUTINE visc_sutherland
C
C     Calculates coefficient of viscosity for a given temperature
C     using Sutherland's Law.
C
C     Input : Temperature in K or R
C     Output: Viscosity in kg/(s m) or lbf s/ft^2
C
      IMPLICIT NONE
      REAL Ac, Tc, visc, temp
      INTEGER iunit
      CHARACTER*1 answer
      CHARACTER*7 temp_unit
      CHARACTER*10 visc_unit

      WRITE(*,*)
      WRITE(*,*)'*********************************'
      WRITE(*,*)'******* Sutherlands Law   *******'
      WRITE(*,*)'*******                   *******'
      WRITE(*,*)'******* mu = Ac * T**1.5  *******'
      WRITE(*,*)'*******           ------  *******'
      WRITE(*,*)'*******           T + Tc  *******'
      WRITE(*,*)'*******                   *******'
      WRITE(*,*)'*********************************'
      WRITE(*,*)

      WRITE(*,*)
      WRITE(*,*)'What units are you working in'
      WRITE(*,*)
      WRITE(*,*)'1.  English Units'
      WRITE(*,*)'2.  SI Units'
      WRITE(*,*)
      WRITE(*,999)'Please enter your choice: '
      READ(*,*) iunit

      IF (iunit .EQ. 1) THEN
        temp_unit = 'Rankine'
        Ac = 2.27E-8
        Tc = 198.6
        visc_unit = 'lbf s/ft^2'
      ELSE
        temp_unit = 'Kelvin'
        Ac = 1.458E-6
        Tc = 110.4
        visc_unit = 'kg / (s m)'
      ENDIF

      IF (iunit .LT. 0) THEN
        WRITE(*,*)
        WRITE(*,*)'Current defaults for constants are:'
        WRITE(*,300) Ac, visc_unit
        WRITE(*,301) Tc, temp_unit
        WRITE(*,*)
        WRITE(*,*)'Do you want to run with these default constants? '
        READ(*,*) answer
	  WRITE(*,*) answer
        IF (answer .EQ. 'n' .OR. answer .EQ. 'N') THEN
          WRITE(*,999)'Enter Ac and Tc (in proper units): '
          READ(*,*) Ac, Tc
        ENDIF
      ENDIF

      WRITE(*,100) temp_unit
      READ(*,*) temp

      visc = Ac * (temp**1.5/(temp + Tc))
      WRITE(*,200) visc, visc_unit

 100  FORMAT('Please supply temperature (',a7,'): ',$)
 200  FORMAT(/,'Molecular viscosity = ',1pE13.6,' ',a10)
 300  FORMAT(/,'   Ac = ',1pE13.6,' ',a10)
 301  FORMAT(/,'   Tc = ',1pE13.6,' ',a10)
 999  FORMAT(a,$)

      RETURN
      END
